@@ -5,7 +5,7 @@
 **
 ** Comments: Dump ARP / RARP header information
 **
-** $Id: arp.c,v 1.20 2001/10/19 15:24:56 mborella Exp $
+** $Id: arp.c,v 1.21 2007/06/25 11:41:13 farooq-i-azam Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ strmap_t arp_opcode_map[] =
   { ARP_OPCODE_REQUEST,  "request" },
   { ARP_OPCODE_REPLY,    "reply" },
   { RARP_OPCODE_REQUEST, "RARP request" },
-  { ARP_OPCODE_REPLY,    "RARP reply" },
+  { RARP_OPCODE_REPLY,   "RARP reply" },
   { 0, "" }
 };
 
@@ -160,16 +160,9 @@ void dump_arp(packet_t *pkt)
   if (my_args->m)
     {
       display_minimal_string("| ARP ");
-      switch(arp.opcode)
-	{
-	case ARP_OPCODE_REQUEST:
-	case ARP_OPCODE_REPLY:
-	  display_minimal_string(map2str(arp_opcode_map, arp.opcode));
-	  display_minimal_string(" ");
-	  break;
-	default:
-	  break;
-	}
+
+      display_minimal_string(map2str(arp_opcode_map, arp.opcode));
+      display_minimal_string(" ");
     }
   else
     {
@@ -216,7 +209,8 @@ void dump_arp(packet_t *pkt)
   switch(arp.hwaddr_format)
     {
     case ARP_HWTYPE_ETHERNET: 
-      
+    case ARP_HWTYPE_IEEE802:
+  
       switch(arp.protoaddr_format)
 	{
 	case ETHERTYPE_IP:
