@@ -5,7 +5,7 @@
 **
 ** Comments: Dump DHCP header information.  See RFCs 2131 and 2132.
 **
-** $Id: dhcp.c,v 1.15 2002/01/03 00:04:01 mborella Exp $
+** $Id: dhcp.c,v 1.22 2007/06/25 12:57:52 farooq-i-azam Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -187,7 +187,8 @@ void dump_dhcp(packet_t *pkt)
       display_ipv4("Your addr", (u_int8_t *) &dhcp.yiaddr);
       display_ipv4("Next server addr", (u_int8_t *) &dhcp.siaddr);
       display_ipv4("Relay agent addr", (u_int8_t *) &dhcp.giaddr);
-      printf("Client hardware addr:   \n");
+      display ("Client hardware addr:", (u_int8_t *) dhcp.chaddr, dhcp.hlen,
+			DISP_HEXCOLONS );
     }
 
   /*
@@ -274,10 +275,16 @@ void dump_dhcp(packet_t *pkt)
 	    display("  Offset", (u_int8_t *) holder, len, DISP_DEC);
 	  break;
 
-	case DHCP_OPTION_ROUTER: /* 3 */
-	case DHCP_OPTION_TIMESERVER: /* 4 */
-	case DHCP_OPTION_NAMESERVER: /* 5 */
-	case DHCP_OPTION_DNS: /* 6 */
+	case DHCP_OPTION_ROUTER:	/* 3 */
+	case DHCP_OPTION_TIMESERVER: 	/* 4 */
+	case DHCP_OPTION_NAMESERVER: 	/* 5 */
+	case DHCP_OPTION_DNS: 		/* 6 */
+	case DHCP_OPTION_LOGSERVER: 	/* 7 */
+	case DHCP_OPTION_COOKIESERVER:	/* 8 */
+	case DHCP_OPTION_LPRSERVER:	/* 9 */
+	case_DHCP_OPTION_IMPRESSSERVER:	/* 10 */
+	case_DHCP_OPTION_RESLOCSERVER:	/* 11 */
+	case_DHCP_OPTION_SWAPSERVER:	/* 16 */
 	case DHCP_OPTION_NETBIOSNAMESERV: /* 44 */
 	  j = 0;
 	  while (j < len / 4)
@@ -403,6 +410,13 @@ void dump_dhcp(packet_t *pkt)
 	case DHCP_OPTION_MAXDHCPMSGSIZE: /* 57 */
 	  if (get_packet_bytes((u_int8_t *) holder, pkt, len) == 0)
 	    return;
+
+	/*
+	 * Conversion
+	 */
+
+	*holder = ntohs ( *holder );
+
 	  if (!my_args->m)
 	    display("  Size", (u_int8_t *) holder, 2, DISP_DEC);
 	  break;
