@@ -6,7 +6,7 @@
 **
 ** Header Definitions for dynamic port mapping
 **
-** $Id: dynports.h,v 1.1 2001/04/02 23:18:28 mborella Exp $
+** $Id: dynports.h,v 1.3 2001/10/11 20:43:50 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,8 +29,6 @@
 
 #include "global.h"
 #include "ip_services.h"
-#include "rtp.h"
-#include "mobileip.h"
 
 /*
  * Function prototypes
@@ -38,5 +36,8 @@
 
 void           dynports_parse(char *);
 service_func_t dynports_find(u_int16_t);
+void           dynports_add(u_int16_t, service_func_t, unsigned long);
+void           dynports_refresh(u_int16_t, service_func_t);
+void           dynports_timeout(void);
 
 #endif
