@@ -5,7 +5,7 @@
 **
 ** Comments: Generic routing encapsulation header file
 **
-** $Id: gre.h,v 1.2 2001/01/20 00:30:31 mborella Exp $
+** $Id: gre.h,v 1.3 2001/03/28 00:43:18 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,11 +29,39 @@
 #include "global.h"
 #include "local.h"
 
+/*
+ * GRE version 0 header (RFC 1701)
+ */
+
+typedef struct gre_v0_rfc1701
+{
+#ifdef WORDS_BIGENDIAN
+  u_int8_t  c:1,
+            r:1,
+            k:1,
+            S:1,
+            s:1,
+	    recur:3;
+  u_int8_t  flags:5,
+            version:3;
+#else
+  u_int8_t  recur:3,
+            s:1,
+            S:1,
+            k:1,
+            r:1,
+            c:1;
+  u_int8_t  version:3,
+            flags:5;
+#endif
+  u_int16_t protocol;
+} gre_v0_rfc1701_t;
+
 /*
  * GRE version 0 header (RFC 2784)
  */
 
-typedef struct gre_v0
+typedef struct gre_v0_rfc2784
 {
 #ifdef WORDS_BIGENDIAN
   u_int8_t  c:1,
@@ -47,7 +75,7 @@ typedef struct gre_v0
             reserved_low:5;
 #endif
   u_int16_t protocol;
-} gre_v0_t;
+} gre_v0_rfc2784_t;
 
 /*
  * GRE version 1 header (used for PPTP, etc.)
