@@ -7,7 +7,7 @@
 ** Sniffs all packets on the link and dumps the fields of the data link, 
 ** IP, TCP, and UDP headers.  
 **
-** $Id: ipgrab.c,v 1.18 2001/11/15 19:28:45 mborella Exp $
+** $Id: ipgrab.c,v 1.22 2007/06/25 10:47:53 farooq-i-azam Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,7 +38,6 @@
 char          * pcap_cmd;  /* command string for pcap */
 pcap_t        * pd;        /* pcap device descriptor */
 int             cnt;       /* number of packets to read */
-pcap_handler    dev_prcsr; /* ptr to func that processes packet for a device */
 pcap_dumper_t * p;         /* pointer to pcap dump file for writing */
 struct arg_t  * my_args;   /* Command line arguments */
 
@@ -107,7 +106,14 @@ int main(int argc, char *argv[])
   
   if (my_args->P)
     dynports_parse(my_args->P);
-  
+
+  /*
+   * Copy filter command into a string only if there is a command.  
+   */
+
+  if (my_args->optind)
+    pcap_cmd = argv2str (&argv[my_args->optind]);
+ 
   /*
    * If we're reading a file, do things in a generic fashion.  Otherwise
    * use standard libpcap functions to do a live read.
@@ -158,12 +164,6 @@ int main(int argc, char *argv[])
       signal(SIGQUIT, (sighandler_t) cleanup_pcap);
       signal(SIGABRT, (sighandler_t) cleanup_pcap);
 
-      /* 
-       * Copy filter command into a string only if there is a command
-       */
-      
-      if (my_args->optind)
-	pcap_cmd = argv2str(&argv[my_args->optind]);
       
       /*
        * Open the pcap device for sniffing
@@ -260,6 +260,15 @@ RETSIGTYPE cleanup_pcap(void)
 {
   struct pcap_stat stats;
 
+  /*
+   * If we aborted because no device was found, then no need
+   * of further processing.
+   */
+
+  if (!pd)
+    exit ( EXIT_FAILURE );
+
+
   if (pcap_stats(pd, &stats) < 0)
     fprintf(stderr, "pcap_stats: %s\n", pcap_geterr(pd));
   else 
@@ -290,6 +299,14 @@ RETSIGTYPE cleanup_pcap(void)
 
 RETSIGTYPE cleanup (void)
 {
+  /* Free memory allocated in parse_cl:Cmdline() */
+  free_args ( my_args );
+
+  /* Display the stats */
   stats_dump();
+
+  /* Let's close the program with a delimitor */
+  display_header_line ( HEADERLINE_DASHES );
+
   exit(0);
 }
