@@ -5,7 +5,7 @@
 **
 ** Comments: Generic IPv6 header structure.
 **
-** $Id: ipv6.h,v 1.8 2000/08/30 20:23:04 mborella Exp $
+** $Id: ipv6.h,v 1.9 2001/10/11 20:43:50 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,27 +29,6 @@
 #include "global.h"
 #include "local.h"
 
-typedef struct ipv6_header
-{
-#if defined(WORDS_BIGENDIAN)
-  u_int8_t       version:4, 
-                 traffic_class_high:4;
-  u_int8_t       traffic_class_low:4,
-                 flow_label_high:4;
-#else
-  u_int8_t       traffic_class_high:4,
-                 version:4;
-  u_int8_t       flow_label_high:4,
-                 traffic_class_low:4;
-#endif
-  u_int16_t      flow_label_low;
-  u_int16_t      payload_length;
-  u_int8_t       next_header;
-  u_int8_t       hop_limit;
-  u_int8_t       src_addr[16];
-  u_int8_t       dst_addr[16];
-} ipv6_header_t;
-
 void dump_ipv6(packet_t *);
 
 #endif
