@@ -5,7 +5,7 @@
 **
 ** Dump IPX/RIP header information
 **
-** $Id: ipxrip.c,v 1.7 2001/05/28 19:24:04 mborella Exp $
+** $Id: ipxrip.c,v 1.8 2002/01/03 00:04:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 
 #include "ipxrip.h"
 
+#define HOLDER_SIZE 64
+
 strmap_t ipxrip_command_map [] =
 {
   { IPXRIP_COMMAND_REQUEST,   "request" },
@@ -47,7 +49,7 @@ void dump_ipxrip(packet_t *pkt)
 {
   ipxrip_header_t  rip;
   ipxrip_entry_t   e;
-  char holder[64];
+  char holder[HOLDER_SIZE];
   u_int8_t count = 0;
  
   /* Set the layer */
@@ -82,8 +84,8 @@ void dump_ipxrip(packet_t *pkt)
       display_header_banner("IPX RIP Header");
       
       /* operation */
-      sprintf(holder, "%d (%s)", rip.op, map2str(ipxrip_command_map, 
-						 rip.op));
+      snprintf(holder, HOLDER_SIZE, "%d (%s)", rip.op, 
+	       map2str(ipxrip_command_map, rip.op));
       display("Operation", (u_int8_t *) holder, strlen(holder), DISP_STRING);
       
       /*
