@@ -13,7 +13,7 @@
 ** and when you can't find the value anywhere else, look in:
 ** draft-ietf-ipsec-ike-01 "The Internet Key Exchange (IKE)"
 **
-** $Id: isakmp.c,v 1.10 2001/05/28 19:24:04 mborella Exp $
+** $Id: isakmp.c,v 1.11 2007/06/25 13:03:00 farooq-i-azam Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -912,8 +912,8 @@ void dump_isakmp(packet_t * pkt)
   major = isakmp.maj_version;
   minor = isakmp.min_version;
   e_flag = isakmp.flags & ISAKMP_FLAG_ENCRYPTION;
-  c_flag = isakmp.flags & ISAKMP_FLAG_COMMIT;
-  a_flag = isakmp.flags & ISAKMP_FLAG_AUTHONLY;
+  c_flag = isakmp.flags & ISAKMP_FLAG_COMMIT >> 1;
+  a_flag = isakmp.flags & ISAKMP_FLAG_AUTHONLY >> 2;
 
   /*
    * Dump header
