@@ -6,7 +6,7 @@
 **
 ** Comments: Dump L2TP header information
 **
-** $Id: l2tp.c,v 1.10 2001/10/12 21:45:02 mborella Exp $
+** $Id: l2tp.c,v 1.11 2007/06/25 13:08:18 farooq-i-azam Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -316,7 +316,7 @@ int dump_l2tp_avp(packet_t * pkt, u_int16_t *n)
       u_int8_t * attribute;
       int real_length = length - 6;
 
-      attribute = (u_int8_t *) my_malloc(real_length + 1);
+      attribute = (u_int8_t *) my_malloc(real_length);
       if (get_packet_bytes((u_int8_t *) attribute, pkt, real_length) == 0)
 	{
 	  my_free(attribute);
