@@ -5,7 +5,7 @@
 **
 ** Comments: LCP module.
 **
-** $Id: lcp.c,v 1.10 2001/10/02 18:37:43 mborella Exp $
+** $Id: lcp.c,v 1.11 2007/06/25 11:47:56 farooq-i-azam Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -44,8 +44,6 @@
 #define LCP_CODE_DISCREQ        11
 #define LCP_CODE_IDENTIFICATION 12
 #define LCP_CODE_TIMEREMAINING  13
-#define LCP_CODE_RESETREQ       14
-#define LCP_CODE_RESETREP       15
 
 /*
  * LCP code map
@@ -66,8 +64,6 @@ strmap_t lcp_code_map[] =
   { LCP_CODE_DISCREQ,        "Discard-Request" },
   { LCP_CODE_IDENTIFICATION, "Identification" },
   { LCP_CODE_TIMEREMAINING,  "Time-Remaining" },
-  { LCP_CODE_RESETREQ,       "Reset-Request" },
-  { LCP_CODE_RESETREP,       "Reset-Replay" },
   { 0, ""}
 };
 
@@ -345,6 +341,7 @@ void dump_lcp(packet_t *pkt)
 	case LCP_CODE_ECHOREP:
 	case LCP_CODE_DISCREQ:
 	case LCP_CODE_IDENTIFICATION:
+	case LCP_CODE_TIMEREMAINING:
 	  {
 	    u_int32_t  magic_number;
 	    u_int8_t * data;
@@ -401,9 +398,54 @@ void dump_lcp(packet_t *pkt)
 	  dump_lcp(pkt);
 	  break;
 
+	/**
+	 * In this case, the payload contains two-byte rejected protocol
+	 * field, followed by which is the rejected information.
+	 **/
+
 	case LCP_CODE_PROTREJ:
 	  {
+	    u_int16_t 	proto;
+	    u_int8_t	* data;
+	    u_int8_t	data_len;	    
+	
+	    /*
+	     * Get the rejected protocol field
+	     */
+	    if (get_packet_bytes((u_int8_t *) &proto, pkt, 2) == 0)
+	      return;    
+
+	    if (my_args->m)
+	      {
+	        display_minimal((u_int8_t *) &proto, 2, DISP_HEX);
+		display_minimal_string(" ");
+	      }
+    	    else	
+	      {
+	        display("Rejected Protocol", (u_int8_t *) &proto, 2, DISP_HEX);	
+  	      }	
+	    /*
+	     * Read and display the protocol data if any
+	     */	    
 	    
+	    data_len = lcp.length - sizeof(lcp_t) - 2;
+
+	    if (data_len > 0)
+	      {
+		data = (u_int8_t *) my_malloc(data_len);
+
+		if (get_packet_bytes(data, pkt, data_len) == 0)
+		  {
+		    my_free(data);
+		    return;
+		  }
+		if (!my_args->m)
+		  {
+		    display("Rejected Data", data, data_len, DISP_HEX);
+		  }
+	
+		my_free(data);
+	      } /* if */
 	  }
 	  break;
 
