@@ -5,7 +5,7 @@
 **
 ** Comments: Includes the ipgrab header files commonly needed.
 **
-** $Id: local.h,v 1.4 2001/05/28 19:24:04 mborella Exp $
+** $Id: local.h,v 1.6 2001/11/15 20:15:59 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@
 #include "utilities.h"
 #include "stats.h"
 #include "layers.h"
+#include "state.h"
+#include "ip_services.h"
 
 /*
  * This is a stupid hack to get around forcing signal handlers to take
