@@ -5,7 +5,7 @@
 **
 ** Comments: Packet manipulation routines
 **
-** $Id: packet_manip.c,v 1.15 2001/09/07 22:50:31 mborella Exp $
+** $Id: packet_manip.c,v 1.16 2001/10/09 23:20:42 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -189,6 +189,67 @@ inline int get_packet_line(u_int8_t *dst, u_int32_t max, packet_t *p)
   return ret;
 }
 
+/*----------------------------------------------------------------------------
+**
+** get_packet_string()
+**
+** Get a \0 terminated string of text from the packet.
+**
+** NOTE: This is NOT a safe function. The caller MUST allocate enough memory 
+** in the destination array.
+**
+** Returns 0 if operation fails and no write occurs.
+** Returns number of bytes read otherwise.
+**----------------------------------------------------------------------------
+*/
+
+inline int get_packet_string(u_int8_t *dst, u_int32_t max, packet_t *p)
+{
+  u_int8_t * ptr;
+  int        ret;
+
+  /*
+   * Find the next \0
+   */
+  
+  ptr = p->current;
+  while (ptr < p->apparent_end && (ptr - p->current) < max - 1)
+    {
+      if (*ptr == '\0')
+	break;
+      ptr++;
+    }
+
+  /*
+   * If we reached the end, then there's no line to read, fail.
+   */
+
+  if (ptr >= p->apparent_end)
+    return 0;
+
+  /* 
+   * Do the copy (NOTE, we do not copy the \0)
+   * We add a \0 in the appropriate place.
+   */
+
+  memcpy(dst, p->current, ptr - p->current);
+  dst[ptr - p->current] = '\0';
+  hexbuffer_add(p->current, ptr - p->current);
+
+  /* 
+   * Increment the current pointer past the \0
+   */
+
+  ret = ptr - p->current;
+  p->current += ret + 1;
+
+  /* 
+   * Return successfully the length of the text
+   */
+
+  return ret;
+}
+
 /*----------------------------------------------------------------------------
 **
 ** look_packet_bytes()
