@@ -2,9 +2,9 @@
 **
 ** parse_cl.c
 **
-** Fri Sep  7 14:32:42 2001
+** Sun Oct  7 12:44:00 2001
 ** Linux 2.4.2 (#5 Thu Apr 26 12:29:16 CDT 2001) i686
-** mborella@stratos (Mike Borella)
+** mborella@stratos.mw.3com.com (Mike Borella)
 **
 ** C file for command line parser
 **
@@ -31,7 +31,7 @@
 
 void usage(char *executable)
 {
-  printf("usage: %s [ -abcdilmnPprTtwxhv ] \n", executable);
+  printf("usage: %s [ -abcCdilmnPprTtwxhv ] \n", executable);
   printf("  [ -a ] ");
   printf("(");
   printf("type=");
@@ -52,6 +52,13 @@ void usage(char *executable)
   printf(" range=1...,");
   printf(")\n");
   printf("         Exit after receiving 'count' packets\n");
+  printf("  [ -C ] ");
+  printf("[ --CCP  ] ");
+  printf("(");
+  printf("type=");
+  printf("STRING");
+  printf(")\n");
+  printf("         CCP compression algorithm\n");
   printf("  [ -d ] ");
   printf("(");
   printf("type=");
@@ -153,11 +160,7 @@ void usage(char *executable)
 
 void free_args(struct arg_t *my_args)
 {
-  if (my_args->i != NULL) free(my_args->i);
-  if (my_args->P != NULL) free(my_args->P);
-  if (my_args->r != NULL) free(my_args->r);
-  if (my_args->w != NULL) free(my_args->w);
-  free(my_args);
+  my_free(my_args);
 }
 
 /*----------------------------------------------------------------------------
@@ -182,6 +185,7 @@ struct arg_t *Cmdline(int argc, char *argv[])
     {"", 0, 0, 'a'},
     {"", 0, 0, 'b'},
     {"count", 1, 0, 'c'},
+    {"CCP", 1, 0, 'C'},
     {"", 0, 0, 'd'},
     {"interface", 1, 0, 'i'},
     {"", 0, 0, 'l'},
@@ -199,10 +203,11 @@ struct arg_t *Cmdline(int argc, char *argv[])
     {0, 0, 0, 0}
   };
 
-  my_args = (struct arg_t *) malloc (sizeof(struct arg_t));
+  my_args = (struct arg_t *) my_malloc (sizeof(struct arg_t));
 
   my_args->a = false;
   my_args->b = false;
+  my_args->C = NULL;
   my_args->d = false;
   my_args->i = NULL;
   my_args->l = false;
@@ -218,7 +223,7 @@ struct arg_t *Cmdline(int argc, char *argv[])
   my_args->h = false;
   my_args->v = false;
 
-  while ((c = getopt_long(argc, argv, "abc:di:lmnP:pr:Ttw:xhv", long_options, &option_index)) != EOF)
+  while ((c = getopt_long(argc, argv, "abc:C:di:lmnP:pr:Ttw:xhv", long_options, &option_index)) != EOF)
     {
       switch(c)
         {
@@ -239,6 +244,10 @@ struct arg_t *Cmdline(int argc, char *argv[])
             }
           break;
 
+        case 'C': 
+          my_args->C = strdup(optarg);
+          break;
+
         case 'd': 
           my_args->d = true;
           break;
