@@ -2,9 +2,9 @@
 **
 ** parse_cl.h
 **
-** Fri Sep  7 14:32:42 2001
+** Sun Oct  7 12:44:00 2001
 ** Linux 2.4.2 (#5 Thu Apr 26 12:29:16 CDT 2001) i686
-** mborella@stratos (Mike Borella)
+** mborella@stratos.mw.3com.com (Mike Borella)
 **
 ** Header file for command line parser
 **
@@ -29,6 +29,7 @@ struct arg_t
   bool a;
   bool b;
   int c;
+  char * C;
   bool d;
   char * i;
   bool l;
