@@ -5,7 +5,7 @@
 **
 ** Comments: PPP module.
 **
-** $Id: pppoe.c,v 1.4 2001/03/27 20:45:36 mborella Exp $
+** $Id: pppoe.c,v 1.5 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -120,6 +120,9 @@ int dump_pppoe_hdr(packet_t *pkt)
   pppoe_t pppoe;
   int len;
 
+  /* Set the layer */
+  set_layer(LAYER_DATALINK);
+
   /*
    * Get the header
    */
@@ -133,23 +136,19 @@ int dump_pppoe_hdr(packet_t *pkt)
    * Dump the header
    */
   
-  if (!my_args->l)
+  if (my_args->m)
     {
-      if (my_args->m)
-	{
-	  display_minimal_string("| PPPOE ");
-	}
-      else
-	{
-	  display_header_banner("PPPOE Header");
-	  display("Version/Type", &pppoe.vertype, 1, DISP_HEX);
-	  display("Session ID", (u_int8_t *) &pppoe.session, 2, DISP_HEX);
-	  display("Length", (u_int8_t *) &len, 2, DISP_DEC);
-	  display_strmap_hex("Message code", pppoe.code, pppoe_code_map);
-	}
-      
+      display_minimal_string("| PPPOE ");
     }
-
+  else
+    {
+      display_header_banner("PPPOE Header");
+      display("Version/Type", &pppoe.vertype, 1, DISP_HEX);
+      display("Session ID", (u_int8_t *) &pppoe.session, 2, DISP_HEX);
+      display("Length", (u_int8_t *) &len, 2, DISP_DEC);
+      display_strmap_hex("Message code", pppoe.code, pppoe_code_map);
+    }
+  
   /* dump the hex buffer */
   hexbuffer_flush();
     
@@ -176,7 +175,7 @@ void dump_pppoed(packet_t *pkt)
   totlen = dump_pppoe_hdr(pkt);
 
   /* do no more if we don't need to */
-  if ((my_args->l)||(my_args->m)) 
+  if (my_args->m) 
     return;
     
   /* dump the TLVs */
