@@ -5,7 +5,7 @@
 **
 ** Comments: Dump PPTP information
 **
-** $Id: pptp.c,v 1.11 2001/05/28 19:24:04 mborella Exp $
+** $Id: pptp.c,v 1.12 2001/10/02 18:37:43 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -355,8 +355,8 @@ void dump_pptp_setlinkinfo(packet_t *pkt)
     {
       display("Peer call ID", (u_int8_t *) &hdr.peer_call_id, 2, DISP_DEC);
       display("Reserved", (u_int8_t *) &hdr.reserved1, 2, DISP_DEC);
-      display("Send ACCM", (u_int8_t *) &hdr.send_accm, 4, DISP_DEC);
-      display("Receive ACCM", (u_int8_t *) &hdr.receive_accm, 4, DISP_DEC);
+      display("Send ACCM", (u_int8_t *) &hdr.send_accm, 4, DISP_HEX);
+      display("Receive ACCM", (u_int8_t *) &hdr.receive_accm, 4, DISP_HEX);
     }
 }
 
