@@ -5,7 +5,7 @@
 **
 ** Comments: Structure of RTP packets
 **
-** $Id: rtp.h,v 1.4 2001/04/02 23:18:28 mborella Exp $
+** $Id: rtp.h,v 1.5 2001/10/11 20:43:50 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,34 +29,6 @@
 #include "global.h"
 #include "local.h"
 
-/*
- * Static part of RTP header
- */
-
-typedef struct rtp_header
-{
-#if defined(WORDS_BIGENDIAN)
-  u_int16_t payload_type:7,
-            marker:1,
-            csrc_count:4,
-            extension:1,
-            padding:1,
-            version:2;
-#else
-  u_int16_t version:2,
-            padding:1,
-            extension:1,
-            csrc_count:4,
-            marker:1,
-            payload_type:7;
-#endif
-  u_int16_t seqno;
-  u_int32_t timestamp;
-  u_int32_t ssrc;
-  
-} rtp_header_t;
-
-
 void dump_rtp(packet_t *);
 
 #endif
