@@ -9,7 +9,7 @@
 ** Maybe we'll try to "decode" these headers into something intelligble 
 ** later...
 **
-** $Id: sdp.c,v 1.7 2001/05/18 21:54:16 mborella Exp $
+** $Id: sdp.c,v 1.8 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -48,6 +48,9 @@ void dump_sdp(packet_t *pkt, int length)
   int  len;
   int  total_length = 0;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   if (my_args->m)
     {
       display_minimal_string("SDP ");
