@@ -7,7 +7,7 @@
 ** fancy with this - I just dump the plaintext headers.  This makes 
 ** debugging easier since parsing is such a pain to get right.
 **
-** $Id: sip.c,v 1.8 2001/05/18 21:54:16 mborella Exp $
+** $Id: sip.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -54,6 +54,9 @@ void dump_sip(packet_t *pkt)
   int seen_nonws;
   int content_length=0;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   if (!my_args->m)
     {
       /* announcement */
