@@ -5,7 +5,7 @@
 **
 ** Comments: Dump SPX header information
 **
-** $Id: spx.c,v 1.5 2001/03/27 20:45:36 mborella Exp $
+** $Id: spx.c,v 1.6 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -41,6 +41,9 @@ void dump_spx(packet_t *pkt)
 {
   spx_header_t spx;
 
+  /* Set the layer */
+  set_layer(LAYER_TRANSPORT);
+
   /*
    * Get the SPX header
    */
