@@ -6,7 +6,7 @@
 ** Comments: General utility functions that are not tied to IPgrab in any
 ** particular way.
 **
-** $Id: utilities.c,v 1.8 2002/01/02 18:16:39 mborella Exp $
+** $Id: utilities.c,v 1.13 2007/06/25 10:14:49 farooq-i-azam Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -192,7 +192,6 @@ inline void dump_hex_and_text(char * buffer, int len)
   char   charbuf [BUF_SIZE];
   char * buf_ptr;
   char * buf_end;
-  int    col;
   int    i;
 
   /* Set the start and end pointers */
@@ -202,7 +201,6 @@ inline void dump_hex_and_text(char * buffer, int len)
   /* Scan each subset and display in hex and ascii format */
   do
     {
-      col = 0;
       memset(hexbuf, 0, BUF_SIZE);
       memset(charbuf, 0, BUF_SIZE);
 
@@ -213,9 +211,9 @@ inline void dump_hex_and_text(char * buffer, int len)
 	      snprintf(hexbuf+(i*3), BUF_SIZE-1,"%.2X ",buf_ptr[0] & 0xFF);
 	      
 	      if(*buf_ptr > 0x1F && *buf_ptr < 0x7E)
-		snprintf(charbuf+i+col, BUF_SIZE-1,"%c",buf_ptr[0]);
+		snprintf(charbuf+i, BUF_SIZE-1,"%c",buf_ptr[0]);
 	      else
-		snprintf(charbuf+i+col, BUF_SIZE-1, ".");
+		snprintf(charbuf+i, BUF_SIZE-1, ".");
 	      
 	      buf_ptr++;
             }
